==> packed_packs-fabric-2.0.2%2B1.21.9-sources.jar: io/github/fishstiz/packed_packs/transform/mixin/gui/MinecraftMixin.java <==
package io.github.fishstiz.packed_packs.transform.mixin.gui;

import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import io.github.fishstiz.packed_packs.config.Config;
import io.github.fishstiz.packed_packs.gui.metadata.PackSelectionScreenArgs;
import io.github.fishstiz.packed_packs.gui.screens.PackedPacksScreen;
import io.github.fishstiz.packed_packs.transform.mixin.PackSelectionScreenAccessor;
import net.minecraft.class_310;
import net.minecraft.class_437;
import net.minecraft.class_5375;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_310.class)
public abstract class MinecraftMixin {
    @Shadow
    @Nullable
    public class_437 screen;

    @WrapMethod(method = "setScreen")
    private void replacePackScreen(class_437 guiScreen, Operation<Void> original) {
        if (guiScreen instanceof class_5375 packScreen &&
            (((PackSelectionScreenAccessor) packScreen).packed_packs$getPrevious() == null) &&
            !(this.screen instanceof PackedPacksScreen)) {

            PackSelectionScreenArgs args = PackSelectionScreenArgs.extract(packScreen);

            if (Config.get().get(args.packType()).isReplaceOriginal()) {
                ((PackSelectionScreenAccessor) packScreen).invokeCloseWatcher();
                guiScreen = new PackedPacksScreen((class_310) (Object) this, this.screen, args);
            }
        }
        original.call(guiScreen);
    }
}

==> packed_packs-fabric-2.0.3%2B1.21.11-sources.jar: io/github/fishstiz/packed_packs/transform/mixin/gui/MinecraftMixin.java <==
package io.github.fishstiz.packed_packs.transform.mixin.gui;

import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import io.github.fishstiz.packed_packs.config.Config;
import io.github.fishstiz.packed_packs.gui.metadata.PackSelectionScreenArgs;
import io.github.fishstiz.packed_packs.gui.screens.PackedPacksScreen;
import io.github.fishstiz.packed_packs.transform.mixin.PackSelectionScreenAccessor;
import net.minecraft.class_310;
import net.minecraft.class_437;
import net.minecraft.class_5375;
import org.jspecify.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_310.class)
public abstract class MinecraftMixin {
    @Shadow
    @Nullable
    public class_437 screen;

    @WrapMethod(method = "setScreen")
    private void replacePackScreen(class_437 guiScreen, Operation<Void> original) {
        if (guiScreen instanceof class_5375 packScreen &&
            (((PackSelectionScreenAccessor) packScreen).packed_packs$getPrevious() == null) &&
            !(this.screen instanceof PackedPacksScreen)) {

            PackSelectionScreenArgs args = PackSelectionScreenArgs.extract(packScreen);

            if (Config.get().get(args.packType()).isReplaceOriginal()) {
                ((PackSelectionScreenAccessor) packScreen).invokeCloseWatcher();
                guiScreen = new PackedPacksScreen(this.screen, args);
            }
        }
        original.call(guiScreen);
    }
}
